@@ -32,7 +32,7 @@ sub start_gui {
         destroy => sub {
             $window->destroy;
             Gtk2->main_quit;
-            1;
+            TRUE;
         }
     );
     $window->signal_connect(
