@@ -51,7 +51,7 @@ my $files_scanned_label;    # Gtk2::Label
 my $threats_label;          # Gtk2::Label
 my $show;                   # Whether or not to show the preferences button
 
-my $window;                 # Main window
+my $window;                 # Main window/dialog
 my $from_cli;               # from the commandline?
 
 sub filter {
@@ -68,8 +68,6 @@ sub filter {
     # AND we can't scan it, just die.
     # However, if interface is running
     # AND we can't scan it, just return to interface.
-    # "Before we even get started, before we even get started..."
-    # - Eddie Murphy
     if ( !sanity_check( $scanthis ) ) {
         if ( $from && $from eq 'startup' ) {
             Gtk2->main_quit;
@@ -88,9 +86,14 @@ sub filter {
         return;
     }
 
-    # Begin popup 'scanning'
-    $window = Gtk2::Window->new;
+    # Begin popup scanning
+    $window
+        = Gtk2::Dialog->new( undef, undef,
+        [ qw| modal destroy-with-parent no-separator | ],
+        );
     $window->set_deletable( FALSE );
+    $window->set_default_size( 450, 80 );
+
     $window->signal_connect(
         'destroy' => sub {
             if ( !$stopped ) {
@@ -101,9 +104,7 @@ sub filter {
             }
         }
     );
-    $window->set_title( _( 'Virus Scanner' ) );
-    $window->set_border_width( 10 );
-    $window->set_default_size( 450, 80 );
+    $window->set_border_width( 5 );
     $window->set_position( 'center-on-parent' );
 
     my $images_dir = ClamTk::App->get_path( 'images' );
@@ -115,7 +116,7 @@ sub filter {
     }
 
     my $eb = Gtk2::EventBox->new;
-    $window->add( $eb );
+    $window->get_content_area->add( $eb );
     my $white = Gtk2::Gdk::Color->new( 0xFFFF, 0xFFFF, 0xFFFF );
     $eb->modify_bg( 'normal', $white );
 
@@ -289,7 +290,7 @@ sub scan {
     if ( $pb_step ) {
         $pb->set_pulse_step( $pb_step );
     } else {
-        $pb->{ timer } = Glib::Timeout->add( 300, \&progress_timeout, $pb );
+        $pb->{ timer } = Glib::Timeout->add( 200, \&progress_timeout, $pb );
         $root_scan = TRUE;
     }
 
@@ -316,8 +317,10 @@ sub scan {
     # kill it if the user hits the Stop button
     #<<<
     Gtk2->main_iteration while ( Gtk2->events_pending );
+    # Using the verbose (-v) switch gives us the next file
+    # for the display "Scanning $1..."
     $scan_pid
-        = open( $SCAN, '-|', "$command $directive $quoted 2>&1" );
+        = open( $SCAN, '-|', "$command $directive -v $quoted 2>&1" );
     defined( $scan_pid ) or die "couldn't fork: $!\n";
     $window->queue_draw;
     Gtk2->main_iteration while ( Gtk2->events_pending );
@@ -326,6 +329,7 @@ sub scan {
 
     Gtk2->main_iteration while ( Gtk2->events_pending );
     while ( <$SCAN> ) {
+        chomp;
         Gtk2->main_iteration while ( Gtk2->events_pending );
         $window->queue_draw;
 
@@ -333,16 +337,43 @@ sub scan {
         next if ( /^LibClamAV/ );
         next if ( /^\s*$/ );
 
+        if ( /^Scanning (.*?)$/ ) {
+            my $base = decode( 'UTF-8', basename( $1 ) );
+            # Display stuff in popup infobar
+            set_infobar_text(
+                $topbar,
+                # sprintf( _( 'Scanning %s...' ), $dirname )
+                # sprintf( _( 'Scanning %s...' ), $dirname )
+                sprintf( _( 'Scanning %s...' ), $base )
+            );
+            $num_scanned++;
+            if ( !$root_scan ) {
+                my $pb_current = $pb->get_fraction;
+
+                if (   $pb_current + $pb_step <= 0
+                    || $pb_current + $pb_step >= 1.0 )
+                {
+                    $pb_current = .99;
+                } else {
+                    $pb_current += $pb_step;
+                }
+                $pb->set_fraction( $pb_current );
+            }
+
+            Gtk2->main_iteration while ( Gtk2->events_pending );
+            $files_scanned_label->set_text( sprintf _( "Files scanned: %d" ),
+                $num_scanned );
+            $topbar->show_all;
+            Gtk2->main_iteration while ( Gtk2->events_pending );
+            $window->queue_draw;
+            next;
+        }
+
         my ( $file, $status );
         if ( /(.*?): ([^:]+) FOUND/ ) {
             $file   = $1;
             $status = $2;
-        } elsif ( /(.*?): (OK)$/ ) {
-            $file   = $1;
-            $status = $2;
-        }    #else {
-             #warn "something else: file = <$file>, stat = <$status>\n";
-             #}
+        }
 
         # Ensure the file is still there (things get moved)
         # and that it got scanned
@@ -365,18 +396,6 @@ sub scan {
             $dirparse = $dirname;
         }
 
-        #<<<
-        # Display stuff in popup infobar
-        set_infobar_text( $topbar,
-                # sprintf( _( 'Scanning %s...' ), $dirname )
-                # sprintf( _( 'Scanning %s...' ), $dirname )
-                sprintf( _( 'Scanning %s...' ), $dirparse )
-        );
-        #>>>
-        $topbar->show_all;
-        Gtk2->main_iteration while ( Gtk2->events_pending );
-        $window->queue_draw;
-
         # Lots of temporary things under /tmp/clamav;
         # we'll just ignore them.
         $dirs_scanned{ $dirname } = 1
@@ -416,23 +435,6 @@ sub scan {
                 $found_count );
         }
 
-        Gtk2->main_iteration while ( Gtk2->events_pending );
-        $num_scanned++;
-        $files_scanned_label->set_text( sprintf _( "Files scanned: %d" ),
-            $num_scanned );
-
-        if ( !$root_scan ) {
-            my $pb_current = $pb->get_fraction;
-
-            if (   $pb_current + $pb_step <= 0
-                || $pb_current + $pb_step >= 1.0 )
-            {
-                $pb_current = .99;
-            } else {
-                $pb_current += $pb_step;
-            }
-            $pb->set_fraction( $pb_current );
-        }
     }
 
     Gtk2->main_iteration while ( Gtk2->events_pending );
@@ -612,7 +614,7 @@ sub set_infobar_text {
     my $label = Gtk2::Label->new;
     $label->set_text( _( $text ) );
     $label->set_alignment( 0.0, 0.5 );
-    # $label->set_ellipsize( 'middle' );
+    $label->set_ellipsize( 'middle' );
     $bar->get_content_area->add(
             #Gtk2::Label->new( _( $text ) )
             $label
@@ -700,7 +702,7 @@ sub nodirs {
 }
 
 sub progress_timeout {
-    $pb->pulse if ( !$root_scan );
+    $pb->pulse;
 
     return TRUE;
 }
@@ -746,7 +748,7 @@ sub popup {
 
     my $dialog = Gtk2::MessageDialog->new(
         undef,    # no parent
-        [ qw(modal destroy-with-parent) ],
+        [ qw| modal destroy-with-parent | ],
         'info',
         $option ? 'ok-cancel' : 'close',
         $message,
